@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkPolyDataReader extends vtkDataReader
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -35,6 +35,10 @@ public class vtkPolyDataReader extends vtkDataReader
   public void SetOutput(vtkPolyData id0)
     { SetOutput_4(id0); }
 
+  private native int ReadMeshSimple_5(String id0,vtkDataObject id1);
+  public int ReadMeshSimple(String id0,vtkDataObject id1)
+    { return ReadMeshSimple_5(id0,id1); }
+
   public vtkPolyDataReader() { super(); }
 
   public vtkPolyDataReader(long id) { super(id); }
